@@ -27,4 +27,13 @@ __all__ = ['celery_app']
 #     except OperationalError as operational_exception:
 #         errors.append(DatabaseConnectionError(operational_exception, db_conn))
 #     finally:
-#         return errors
\ No newline at end of file
+#         return errors
+
+import os
+import sys
+
+def manage():
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "crm.settings")
+    os.environ.setdefault("DJANGO_CONFIGURATION", 'Production')
+    from django.core.management import execute_from_command_line
+    execute_from_command_line(sys.argv)
\ No newline at end of file
